==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fFmul.h <==
// class soot.coffi.Instruction_Fmul

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 9389f613dac60b1b soot_coffi_Instruction__5fFmul
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fFmul_H_
#define _JC_soot_coffi_Instruction__5fFmul_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fFmul$sub_refs	_jc_soot_coffi_Instruction__5fFmul$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fFmul$sub_nonrefs	_jc_soot_coffi_Instruction__5fFmul$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFmul$refs	_jc_soot_coffi_Instruction__5fFmul$refs;
typedef struct _jc_soot_coffi_Instruction__5fFmul$nonrefs	_jc_soot_coffi_Instruction__5fFmul$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFmul$object	_jc_soot_coffi_Instruction__5fFmul$object;

typedef const struct _jc_soot_coffi_Instruction__5fFmul$vmethods	_jc_soot_coffi_Instruction__5fFmul$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fFmul$vtable	_jc_soot_coffi_Instruction__5fFmul$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fFmul$vtype	_jc_soot_coffi_Instruction__5fFmul$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fFmul$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fFmul$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fFmul$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fFmul$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fFmul$vmethods	soot_coffi_Instruction__5fFmul;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fFmul$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fFmul$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFmul$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFmul$refs {
    _jc_soot_coffi_Instruction__5fFmul$sub_refs	soot_coffi_Instruction__5fFmul;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFmul$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFmul$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fFmul$sub_nonrefs	soot_coffi_Instruction__5fFmul;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fFmul$object {
	_jc_soot_coffi_Instruction__5fFmul$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fFmul$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fFmul$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fFmul$vtype _jc_soot_coffi_Instruction__5fFmul$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fFmul, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fFmul$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fFmul_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fFmul.h <==
// class soot.coffi.Instruction_Fmul

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 9389f613dac60b1b soot_coffi_Instruction__5fFmul
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fFmul_H_
#define _JC_soot_coffi_Instruction__5fFmul_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fFmul$sub_refs	_jc_soot_coffi_Instruction__5fFmul$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fFmul$sub_nonrefs	_jc_soot_coffi_Instruction__5fFmul$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFmul$refs	_jc_soot_coffi_Instruction__5fFmul$refs;
typedef struct _jc_soot_coffi_Instruction__5fFmul$nonrefs	_jc_soot_coffi_Instruction__5fFmul$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFmul$object	_jc_soot_coffi_Instruction__5fFmul$object;

typedef const struct _jc_soot_coffi_Instruction__5fFmul$vmethods	_jc_soot_coffi_Instruction__5fFmul$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fFmul$vtable	_jc_soot_coffi_Instruction__5fFmul$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fFmul$vtype	_jc_soot_coffi_Instruction__5fFmul$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fFmul$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fFmul$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fFmul$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fFmul$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fFmul$vmethods	soot_coffi_Instruction__5fFmul;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fFmul$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fFmul$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFmul$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFmul$refs {
    _jc_soot_coffi_Instruction__5fFmul$sub_refs	soot_coffi_Instruction__5fFmul;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFmul$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFmul$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fFmul$sub_nonrefs	soot_coffi_Instruction__5fFmul;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fFmul$object {
	_jc_soot_coffi_Instruction__5fFmul$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fFmul$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fFmul$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fFmul$vtype _jc_soot_coffi_Instruction__5fFmul$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fFmul, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fFmul$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fFmul_H_ */
